@@ -235,7 +235,7 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
   if verbose_text:
     print('text3(update negadj,negaverb): ', text3)
 
-  ## ---- back , again verb ---
+  ## ---- back , again.etc. + verb phrase ---
   if back_again:
     text3,ba_verbs = abverb(text3,myBA = myBA,myBAverb = myBAverb)
     bavbs = [] 
@@ -243,7 +243,8 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
       vb1 = vb.replace('2vvv','')
       bavbs.append(vb1)
     opi_verbs = opi_verbs +bavbs  
-
+  else:
+    ba_verbs = []
 
   #5. except compounds, other normal words into ADJ, VERB, NOUN 
 
@@ -666,7 +667,7 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
     print('text3(update negadj,negaverb): ', text3)
 
  
-  ## ---- back , again verb ---
+  ## ---- back , again etc. verb phrase ---
   if back_again:
     text3,ba_verbs = abverb(text3,myBA = myBA,myBAverb = myBAverb)
     bavbs = [] 
@@ -675,7 +676,8 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
       bavbs.append(vb1)
     opi_verbs = opi_verbs +bavbs  
 
-
+  else:
+    ba_verbs = []
 
   #5. ecept compounds, other normal words into ADJ, VERB, NOUN 
 
@@ -878,7 +880,7 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
 def targetPlot(text_T, avnEdges,saveAdd =False,image_size = [10,2], font_size = 15, word_close = 5, connectionstyle = "arc,angleA=90,angleB=90,armA=30,armB=35,rad=0.3", node_size = 1000):
   """green curve: Adjective2Noun,  red curve: Verb2Noun,  blue cure: Noun2Noun
      connectionstyle: https://matplotlib.org/stable/gallery/userdemo/connectionstyle_demo.html  
-     # "arc3,rad=0.3" ,  "bar,fraction=-0.3" , "arc,angleA=90,angleB=90,armA=30,armB=35,rad=0.3"
+     ### "arc3,rad=0.3" ,  "bar,fraction=-0.3" , "arc,angleA=90,angleB=90,armA=30,armB=35,rad=0.3"
   """
   
   words = text_T.split()
